assetImage constant
int
const assetImage
Use this when the image path is a Flutter asset (e.g., 'assets/images/...').
Implementation
static const int assetImage = 1;
Use this when the image path is a Flutter asset (e.g., 'assets/images/...').
static const int assetImage = 1;