imageFromWeb constant
int
const imageFromWeb
Use this when the image path is a remote URL (e.g., 'https://...').
Implementation
static const int imageFromWeb = 0;
Use this when the image path is a remote URL (e.g., 'https://...').
static const int imageFromWeb = 0;