localFileImage constant
int
const localFileImage
Use this when the image path is a local file system path (e.g., from path_provider).
Implementation
static const int localFileImage = 2;
Use this when the image path is a local file system path (e.g., from path_provider).
static const int localFileImage = 2;