BodyDefaultAlert class

A widget to display the default body of an alert dialog, including title, description, and action buttons.

Inheritance

Constructors

BodyDefaultAlert({Key? key, required String title, required String description, Color? confirmButtonColor, Color? cancelButtonColor, TextStyle? titleStyle, TextStyle? descriptionStyle, TextStyle? confirmButtonTextStyle, TextStyle? cancelButtonTextStyle, TextAlign? textAlignDescription, Widget? body, String? cancelText, VoidCallback? cancelAction, required double heightButtons, required double buttonCornerRadius, required double cornerRadius, required String confirmText, required VoidCallback confirmAction, bool isHtml = false, VoidCallback? close})
const

Properties

body Widget?
final
buttonCornerRadius double
final
cancelAction VoidCallback?
final
cancelButtonColor Color?
final
cancelButtonTextStyle TextStyle?
final
cancelText String?
final
close VoidCallback?
final
confirmAction VoidCallback
final
confirmButtonColor Color?
final
confirmButtonTextStyle TextStyle?
final
confirmText String
final
cornerRadius double
final
description String
final
descriptionStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
heightButtons double
final
isHtml bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlignDescription TextAlign?
final
title String
final
titleStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited