ImageType class

ImageType defines the available source types for image alerts.

Use these constants when calling AwesomeAlert.showImage.

Constructors

ImageType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

assetImage → const int
Use this when the image path is a Flutter asset (e.g., 'assets/images/...').
imageFromWeb → const int
Use this when the image path is a remote URL (e.g., 'https://...').
localFileImage → const int
Use this when the image path is a local file system path (e.g., from path_provider).